@@ -17,7 +17,9 @@ def get_by_user_id_and_template_id(user_id, template_id):
     Returns:
 
     """
-    return ExploreDataStructure.get_by_user_id_and_template_id(user_id, template_id)
+    return ExploreDataStructure.get_by_user_id_and_template_id(
+        user_id, template_id
+    )
 
 
 def upsert(explore_data_structure):
@@ -29,7 +31,8 @@ def upsert(explore_data_structure):
     Returns:
 
     """
-    return explore_data_structure.save()
+    explore_data_structure.save()
+    return explore_data_structure
 
 
 def create_and_get_explore_data_structure(template, request):
@@ -47,7 +50,7 @@ def create_and_get_explore_data_structure(template, request):
         explore_data_structure = get_by_user_id_and_template_id(
             user_id=str(request.user.id), template_id=template.id
         )
-    except:
+    except Exception:
         # create explore data structure
         explore_data_structure = ExploreDataStructure(
             user=str(request.user.id),
@@ -57,7 +60,9 @@ def create_and_get_explore_data_structure(template, request):
         upsert(explore_data_structure)
         # generate the root element
         root_element = generate_form(
-            template.content, data_structure=explore_data_structure, request=request
+            template.content,
+            data_structure=explore_data_structure,
+            request=request,
         )
         explore_data_structure.data_structure_element_root = root_element
         upsert(explore_data_structure)
