@@ -1,6 +1,6 @@
 """ Persistent Query Example model
 """
-from mongoengine import errors as mongoengine_errors
+from django.core.exceptions import ObjectDoesNotExist
 
 from core_explore_common_app.components.abstract_persistent_query.models import (
     AbstractPersistentQuery,
@@ -11,6 +11,12 @@ from core_main_app.commons import exceptions
 class PersistentQueryExample(AbstractPersistentQuery):
     """Persistent Query Example"""
 
+    class Meta:
+        """Meta"""
+
+        verbose_name = "Persistent Query by Example"
+        verbose_name_plural = "Persistent Queries by Example"
+
     @staticmethod
     def get_by_id(query_id):
         """Get a persistent query example
@@ -22,11 +28,11 @@ class PersistentQueryExample(AbstractPersistentQuery):
 
         """
         try:
-            return PersistentQueryExample.objects().get(pk=query_id)
-        except mongoengine_errors.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
-        except Exception as e:
-            raise exceptions.ModelError(str(e))
+            return PersistentQueryExample.objects.get(pk=query_id)
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
+        except Exception as exception:
+            raise exceptions.ModelError(str(exception))
 
     @staticmethod
     def get_by_name(query_name):
@@ -39,11 +45,11 @@ class PersistentQueryExample(AbstractPersistentQuery):
 
         """
         try:
-            return PersistentQueryExample.objects().get(name=query_name)
-        except mongoengine_errors.DoesNotExist as e:
-            raise exceptions.DoesNotExist(str(e))
-        except Exception as e:
-            raise exceptions.ModelError(str(e))
+            return PersistentQueryExample.objects.get(name=query_name)
+        except ObjectDoesNotExist as exception:
+            raise exceptions.DoesNotExist(str(exception))
+        except Exception as exception:
+            raise exceptions.ModelError(str(exception))
 
     @staticmethod
     def get_all():
@@ -65,7 +71,7 @@ class PersistentQueryExample(AbstractPersistentQuery):
         Returns:
 
         """
-        return PersistentQueryExample.objects(user_id=str(user_id))
+        return PersistentQueryExample.objects.filter(user_id=str(user_id))
 
     @staticmethod
     def get_none():
@@ -74,4 +80,4 @@ class PersistentQueryExample(AbstractPersistentQuery):
         Returns:
 
         """
-        return PersistentQueryExample.objects().none()
+        return PersistentQueryExample.objects.none()
