@@ -1,13 +1,14 @@
 """ Explore Common App tasks
 """
 import logging
-from datetime import timedelta
 
 from celery import shared_task
-from django.utils import timezone
 
 from core_explore_example_app.settings import QUERIES_MAX_DAYS_IN_DATABASE
-from core_explore_example_app.system.api import get_saved_queries_created_by_app
+from core_explore_example_app.system.api import (
+    get_saved_queries_created_by_app,
+)
+from core_main_app.utils.datetime import datetime_now, datetime_timedelta
 
 logger = logging.getLogger(__name__)
 
@@ -24,16 +25,16 @@ def delete_temporary_saved_queries():
         old_queries = [
             query
             for query in get_saved_queries_created_by_app()
-            if query.id.generation_time
-            < timezone.now() - timedelta(days=QUERIES_MAX_DAYS_IN_DATABASE)
+            if query.creation_date
+            < datetime_now()
+            - datetime_timedelta(days=QUERIES_MAX_DAYS_IN_DATABASE)
         ]
         # remove old queries from database
         for query in old_queries:
-            logger.info("Periodic task: delete saved query {}.".format(str(query.id)))
+            logger.info("Periodic task: delete saved query %s.", str(query.id))
             query.delete()
-    except Exception as e:
+    except Exception as exception:
         logger.error(
-            "An error occurred while deleting temporary saved queries ({}).".format(
-                str(e)
-            )
+            "An error occurred while deleting temporary saved queries (%s).",
+            str(exception),
         )
