@@ -4,18 +4,30 @@ from os.path import join
 
 from django.template import loader
 
+from core_main_app.settings import MONGODB_INDEXING
+from xml_utils.xsd_types.xsd_types import (
+    get_xsd_numbers,
+    get_xsd_gregorian_types,
+)
 from core_explore_example_app.utils.xml import get_enumerations
-from xml_utils.xsd_types.xsd_types import get_xsd_numbers, get_xsd_gregorian_types
 
 
-class BranchInfo(object):
+class BranchInfo:
     """Store information about a branch from the xml schema while it is being processed for field selection"""
 
     def __init__(self, keep_the_branch=False, selected_leaves=None):
         self.keep_the_branch = keep_the_branch
-        self.selected_leaves = selected_leaves if selected_leaves is not None else []
+        self.selected_leaves = (
+            selected_leaves if selected_leaves is not None else []
+        )
 
     def add_selected_leaf(self, leaf_id):
+        """add_selected_leaf
+        Args:
+            leaf_id:
+
+        Returns
+        """
         self.selected_leaves.append(leaf_id)
         self.keep_the_branch = True
 
@@ -97,8 +109,9 @@ def prune_li(li):
                 branch_info.keep_the_branch = True
             selected_leaves.extend(ul_branch_info.selected_leaves)
 
-        # sub element queries available when more than one selected elements under the same element
-        if len(selected_leaves) > 1:
+        # sub element queries available when more than one selected elements under the same element,
+        # and data stored in MongoDB
+        if MONGODB_INDEXING and len(selected_leaves) > 1:
             # not for the choices
             if li[0].tag != "select":
                 # TODO: check if test useful
@@ -121,30 +134,10 @@ def prune_li(li):
                 # tells to keep this branch until this leaf
                 branch_info.add_selected_leaf(element_id)
                 return branch_info
-        except:
+        except Exception:
             return branch_info
 
 
-def sub_element_query_li(li, selected_leaves):
-    """Update li with sub-element query attributes
-
-    Args:
-        li:
-        selected_leaves:
-
-    Returns:
-
-    """
-    # not for the choices
-    if li[0].tag != "select":
-        # TODO: check if test useful
-        if "select_class" not in li.attrib:
-            leaves_id = " ".join(selected_leaves)
-            # set element class
-            li.attrib["select_class"] = "parent"
-            li.attrib["select_id"] = leaves_id
-
-
 def add_selection_attributes(element, select_class, select_id=None):
     """Add css attribute to selected element
 
@@ -171,7 +164,9 @@ def render_yes_or_not():
 
     """
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "yes_no.html")
+        join(
+            "core_explore_example_app", "user", "query_builder", "yes_no.html"
+        )
     )
 
 
@@ -182,7 +177,12 @@ def render_and_or_not():
 
     """
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "and_or_not.html")
+        join(
+            "core_explore_example_app",
+            "user",
+            "query_builder",
+            "and_or_not.html",
+        )
     )
 
 
@@ -193,7 +193,12 @@ def render_numeric_select():
 
     """
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "numeric_select.html")
+        join(
+            "core_explore_example_app",
+            "user",
+            "query_builder",
+            "numeric_select.html",
+        )
     )
 
 
@@ -231,7 +236,12 @@ def render_string_select():
 
     """
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "string_select.html")
+        join(
+            "core_explore_example_app",
+            "user",
+            "query_builder",
+            "string_select.html",
+        )
     )
 
 
@@ -242,7 +252,12 @@ def render_initial_form():
 
     """
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "initial_form.html")
+        join(
+            "core_explore_example_app",
+            "user",
+            "query_builder",
+            "initial_form.html",
+        )
     )
 
 
@@ -253,7 +268,9 @@ def render_remove_button():
 
     """
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "remove.html")
+        join(
+            "core_explore_example_app", "user", "query_builder", "remove.html"
+        )
     )
 
 
@@ -281,7 +298,8 @@ def render_enum(enums):
         "enums": enums,
     }
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "enum.html"), context
+        join("core_explore_example_app", "user", "query_builder", "enum.html"),
+        context,
     )
 
 
@@ -298,7 +316,12 @@ def render_new_query(tag_id, query, is_first=False):
     """
     context = {"tagID": tag_id, "query": query, "first": is_first}
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "new_query.html"),
+        join(
+            "core_explore_example_app",
+            "user",
+            "query_builder",
+            "new_query.html",
+        ),
         context,
     )
 
@@ -316,7 +339,12 @@ def render_new_criteria(tag_id):
         "tagID": tag_id,
     }
     return _render_template(
-        join("core_explore_example_app", "user", "query_builder", "new_criteria.html"),
+        join(
+            "core_explore_example_app",
+            "user",
+            "query_builder",
+            "new_criteria.html",
+        ),
         context,
     )
 
@@ -366,7 +394,9 @@ def get_element_comparison(element_field):
     Returns:
 
     """
-    return element_field["comparison"] if "comparison" in element_field else "is"
+    return (
+        element_field["comparison"] if "comparison" in element_field else "is"
+    )
 
 
 def get_user_inputs(element_type, data_structure_element, default_prefix):
@@ -389,7 +419,9 @@ def get_user_inputs(element_type, data_structure_element, default_prefix):
                 user_inputs = render_numeric_select() + render_value_input()
             # gregorian date
             elif element_type in get_xsd_gregorian_types(default_prefix):
-                user_inputs = render_gregorian_strict_match() + render_value_input()
+                user_inputs = (
+                    render_gregorian_strict_match() + render_value_input()
+                )
             # string
             else:
                 user_inputs = render_string_select() + render_value_input()
@@ -397,7 +429,7 @@ def get_user_inputs(element_type, data_structure_element, default_prefix):
             # enumeration
             enums = get_enumerations(data_structure_element)
             user_inputs = render_enum(enums)
-    except:
+    except Exception:
         # default renders string form
         user_inputs = render_string_select() + render_value_input()
 
