@@ -12,7 +12,9 @@ from django.views.generic import View
 import core_explore_example_app.permissions.rights as rights
 import core_main_app.utils.decorators as decorators
 from core_explore_common_app.components.query import api as query_api
-from core_explore_common_app.views.user.ajax import CreatePersistentQueryUrlView
+from core_explore_common_app.views.user.ajax import (
+    CreatePersistentQueryUrlView,
+)
 from core_explore_example_app.apps import ExploreExampleAppConfig
 from core_explore_example_app.commons.exceptions import MongoQueryException
 from core_explore_example_app.components.explore_data_structure import (
@@ -21,7 +23,9 @@ from core_explore_example_app.components.explore_data_structure import (
 from core_explore_example_app.components.persistent_query_example.models import (
     PersistentQueryExample,
 )
-from core_explore_example_app.components.saved_query import api as saved_query_api
+from core_explore_example_app.components.saved_query import (
+    api as saved_query_api,
+)
 from core_explore_example_app.components.saved_query.models import SavedQuery
 from core_explore_example_app.utils.custom_checkbox_renderer import (
     CustomCheckboxRenderer,
@@ -35,7 +39,10 @@ from core_explore_example_app.utils.mongo_query import (
     sub_elements_to_query,
     check_query_form,
 )
-from core_explore_example_app.utils.parser import remove_form_element, get_parser
+from core_explore_example_app.utils.parser import (
+    remove_form_element,
+    get_parser,
+)
 from core_explore_example_app.utils.query_builder import (
     render_initial_form,
     render_new_query,
@@ -45,20 +52,23 @@ from core_explore_example_app.utils.query_builder import (
     get_user_inputs,
 )
 from core_main_app.commons import exceptions
-from core_main_app.commons.exceptions import DoesNotExist
 from core_main_app.components.template import api as template_api
+from core_main_app.utils.query.mongo.prepare import sanitize_value
 from core_parser_app.components.data_structure_element import (
     api as data_structure_element_api,
 )
 from xml_utils.html_tree import parser as html_tree_parser
-from xml_utils.xsd_tree.operations.namespaces import get_namespaces, get_default_prefix
+from xml_utils.xsd_tree.operations.namespaces import (
+    get_namespaces,
+    get_default_prefix,
+)
 
 logger = logging.getLogger(__name__)
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def generate_element(request, explore_data_structure_id):
@@ -76,7 +86,7 @@ def generate_element(request, explore_data_structure_id):
         explore_data_structure = explore_data_structure_api.get_by_id(
             explore_data_structure_id
         )
-        template = template_api.get(
+        template = template_api.get_by_id(
             str(explore_data_structure.template.id), request=request
         )
         xsd_parser = get_parser(request=request)
@@ -86,9 +96,9 @@ def generate_element(request, explore_data_structure_id):
             data_structure=explore_data_structure,
             renderer_class=CustomCheckboxRenderer,
         )
-    except Exception as e:
+    except Exception as exception:
         return HttpResponseBadRequest(
-            "An unexpected error occurred: %s" % escape(str(e)),
+            "An unexpected error occurred: %s" % escape(str(exception)),
             content_type="application/javascript",
         )
 
@@ -96,8 +106,8 @@ def generate_element(request, explore_data_structure_id):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def generate_choice(request, explore_data_structure_id):
@@ -115,7 +125,7 @@ def generate_choice(request, explore_data_structure_id):
         explore_data_structure = explore_data_structure_api.get_by_id(
             explore_data_structure_id
         )
-        template = template_api.get(
+        template = template_api.get_by_id(
             str(explore_data_structure.template.id), request=request
         )
         xsd_parser = get_parser(request=request)
@@ -125,9 +135,9 @@ def generate_choice(request, explore_data_structure_id):
             data_structure=explore_data_structure,
             renderer_class=CustomCheckboxRenderer,
         )
-    except Exception as e:
+    except Exception as exception:
         return HttpResponseBadRequest(
-            "An unexpected error occurred: %s" % escape(str(e)),
+            "An unexpected error occurred: %s" % escape(str(exception)),
             content_type="application/javascript",
         )
 
@@ -135,8 +145,8 @@ def generate_choice(request, explore_data_structure_id):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def remove_element(request):
@@ -154,8 +164,8 @@ def remove_element(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def save_fields(request):
@@ -169,8 +179,8 @@ def save_fields(request):
     """
     try:
         # get parameters form request
-        form_content = request.POST["formContent"]
-        template_id = request.POST["templateID"]
+        form_content = sanitize_value(request.POST["formContent"])
+        template_id = sanitize_value(request.POST["templateID"])
 
         # modify the form string to only keep the selected elements
         html_tree = html_tree_parser.from_string(form_content)
@@ -197,15 +207,19 @@ def save_fields(request):
         # update explore data structure
         explore_data_structure_api.upsert(explore_data_structure)
 
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
-    except Exception as e:
-        logger.error(escape(str(e)))
-        return HttpResponseBadRequest("An error occurred while saving the form.")
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
+    except Exception as exception:
+        logger.error(escape(str(exception)))
+        return HttpResponseBadRequest(
+            "An error occurred while saving the form."
+        )
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def select_element(request):
@@ -234,8 +248,8 @@ def select_element(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def get_sub_elements_query_builder(request):
@@ -254,7 +268,7 @@ def get_sub_elements_query_builder(request):
     list_leaves_id = leaves_id.split(" ")
 
     # get template
-    template = template_api.get(template_id, request=request)
+    template = template_api.get_by_id(template_id, request=request)
 
     # get template namespaces
     namespaces = get_namespaces(template.content)
@@ -266,7 +280,9 @@ def get_sub_elements_query_builder(request):
 
     form_fields = []
     for leaf_id in list_leaves_id:
-        data_structure_element = data_structure_element_api.get_by_id(leaf_id, request)
+        data_structure_element = data_structure_element_api.get_by_id(
+            leaf_id, request
+        )
         element_type = data_structure_element.options["type"]
         element_name = data_structure_element.options["name"]
 
@@ -284,7 +300,9 @@ def get_sub_elements_query_builder(request):
         )
 
     response_dict = {
-        "subElementQueryBuilder": render_sub_elements_query(parent_name, form_fields)
+        "subElementQueryBuilder": render_sub_elements_query(
+            parent_name, form_fields
+        )
     }
     return HttpResponse(
         json.dumps(response_dict), content_type="application/javascript"
@@ -292,8 +310,8 @@ def get_sub_elements_query_builder(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def insert_sub_elements_query(request):
@@ -310,7 +328,7 @@ def insert_sub_elements_query(request):
     criteria_id = request.POST["criteriaID"]
 
     # get template
-    template = template_api.get(template_id, request=request)
+    template = template_api.get_by_id(template_id, request=request)
 
     # get template namespaces
     namespaces = get_namespaces(template.content)
@@ -322,8 +340,12 @@ def insert_sub_elements_query(request):
     errors = check_query_form(form_values, template_id, request=request)
 
     if len(errors) == 0:
-        query = sub_elements_to_query(form_values, namespaces, default_prefix, request)
-        displayed_query = sub_elements_to_pretty_query(form_values, namespaces, request)
+        query = sub_elements_to_query(
+            form_values, namespaces, default_prefix, request
+        )
+        displayed_query = sub_elements_to_pretty_query(
+            form_values, namespaces, request
+        )
         ui_id = "ui" + criteria_id[4:]
         temporary_query = SavedQuery(
             user_id=ExploreExampleAppConfig.name,
@@ -349,8 +371,8 @@ def insert_sub_elements_query(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def update_user_input(request):
@@ -371,14 +393,16 @@ def update_user_input(request):
         from_element_id, request
     )
     # get template
-    template = template_api.get(template_id, request=request)
+    template = template_api.get_by_id(template_id, request=request)
 
     # convert xml path to mongo dot notation
     namespaces = get_namespaces(template.content)
     default_prefix = get_default_prefix(namespaces)
 
     element_type = data_structure_element.options["type"]
-    user_inputs = get_user_inputs(element_type, data_structure_element, default_prefix)
+    user_inputs = get_user_inputs(
+        element_type, data_structure_element, default_prefix
+    )
 
     response_dict = {"userInputs": user_inputs, "element_type": element_type}
     return HttpResponse(
@@ -387,8 +411,8 @@ def update_user_input(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def add_criteria(request):
@@ -422,8 +446,8 @@ def _render_errors(errors):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def clear_criteria(request):
@@ -443,8 +467,8 @@ def clear_criteria(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_delete_query,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_DELETE_QUERY,
     raise_exception=True,
 )
 def clear_queries(request):
@@ -467,8 +491,8 @@ def clear_queries(request):
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_delete_query,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_DELETE_QUERY,
     raise_exception=True,
 )
 def delete_query(request):
@@ -483,15 +507,17 @@ def delete_query(request):
     saved_query_id = request.POST["savedQueryID"]
     try:
         saved_query = saved_query_api.get_by_id(saved_query_id[5:])
-    except DoesNotExist:
-        return HttpResponseBadRequest("The saved query does not exist anymore.")
+    except exceptions.DoesNotExist:
+        return HttpResponseBadRequest(
+            "The saved query does not exist anymore."
+        )
     saved_query_api.delete(saved_query)
     return HttpResponse(json.dumps({}), content_type="application/javascript")
 
 
 @decorators.permission_required(
-    content_type=rights.explore_example_content_type,
-    permission=rights.explore_example_access,
+    content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+    permission=rights.EXPLORE_EXAMPLE_ACCESS,
     raise_exception=True,
 )
 def add_query_criteria(request):
@@ -512,8 +538,10 @@ def add_query_criteria(request):
     # get saved query number from id
     try:
         saved_query = saved_query_api.get_by_id(saved_query_id)
-    except DoesNotExist:
-        return HttpResponseBadRequest("The saved query does not exist anymore.")
+    except exceptions.DoesNotExist:
+        return HttpResponseBadRequest(
+            "The saved query does not exist anymore."
+        )
 
     new_query_html = render_new_query(tag_id, saved_query, is_first)
     response_dict = {"query": new_query_html, "first": is_first}
@@ -523,12 +551,14 @@ def add_query_criteria(request):
 
 
 class GetQueryView(View):
+    """Get Query View"""
+
     fields_to_query_func = None
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_access,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_ACCESS,
             raise_exception=True,
         )
     )
@@ -558,53 +588,64 @@ class GetQueryView(View):
                 query_form = request.POST["queryForm"]
                 request.session["savedQueryFormExplore"] = query_form
 
-            errors = []
             query_object = query_api.get_by_id(query_id, request.user)
-            # set the data-sources sorting value according to the POST request field
-            for data_sources_index in range(len(query_object.data_sources)):
-                # updating only the existing data-sources (the new data-source already got
-                # the default filter value)
-                if data_sources_index in range(0, len(order_by_field_array)):
-                    query_object.data_sources[
-                        data_sources_index
-                    ].order_by_field = order_by_field_array[data_sources_index]
-            if len(query_object.data_sources) == 0:
-                errors.append("Please select at least 1 data source.")
 
-            if len(errors) == 0 and form_values:
-                errors.append(
-                    check_query_form(form_values, template_id, request=request)
-                )
-                query_content = self.fields_to_query_func(
+            # Check that the query fields are correctly filled and formatted.
+            errors = []
+            if len(query_object.data_sources) == 0:
+                errors = ["Please select at least 1 data source."]
+            elif form_values:
+                errors = check_query_form(
                     form_values, template_id, request=request
                 )
-                query_object.content = json.dumps(query_content)
-            elif len(errors) > 0:
+
+            if len(errors) > 0:  # If any error, send it back to the user.
                 return HttpResponseBadRequest(
-                    _render_errors(errors), content_type="application/javascript"
+                    _render_errors(errors),
+                    content_type="application/javascript",
+                )
+
+            # Set the data-sources sorting value according to the POST request field
+            for data_sources_index in range(len(query_object.data_sources)):
+                # updating only the existing data-sources (the new data-source already
+                # got the default filter value).
+                if data_sources_index in range(0, len(order_by_field_array)):
+                    query_object.data_sources[data_sources_index][
+                        "order_by_field"
+                    ] = order_by_field_array[data_sources_index]
+
+            if form_values:
+                query_object.content = json.dumps(
+                    self.fields_to_query_func(
+                        form_values, template_id, request=request
+                    )
                 )
 
             query_api.upsert(query_object, request.user)
 
-            return HttpResponse(json.dumps({}), content_type="application/javascript")
+            return HttpResponse(
+                json.dumps({}), content_type="application/javascript"
+            )
         except exceptions.ModelError:
             return HttpResponseBadRequest(
                 "Invalid input.", content_type="application/javascript"
             )
-        except Exception as e:
+        except Exception as exception:
             return HttpResponseBadRequest(
-                "An unexpected error occurred: %s" % escape(str(e)),
+                "An unexpected error occurred: %s" % escape(str(exception)),
                 content_type="application/javascript",
             )
 
 
 class SaveQueryView(View):
+    """Save Query View"""
+
     fields_to_query_func = None
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_save_query,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_SAVE_QUERY,
             raise_exception=True,
         )
     )
@@ -623,7 +664,9 @@ class SaveQueryView(View):
         # Check that the user can save a query
         if "_auth_user_id" not in request.session:
             error = "You have to login to save a query."
-            return HttpResponseBadRequest(error, content_type="application/javascript")
+            return HttpResponseBadRequest(
+                error, content_type="application/javascript"
+            )
 
         # Check that the query is valid
         errors = check_query_form(form_values, template_id, request=request)
@@ -637,22 +680,27 @@ class SaveQueryView(View):
                 # save the query in the data base
                 saved_query = SavedQuery(
                     user_id=str(request.user.id),
-                    template=template_api.get(template_id, request=request),
+                    template=template_api.get_by_id(
+                        template_id, request=request
+                    ),
                     query=json.dumps(query),
                     displayed_query=displayed_query,
                 )
                 saved_query_api.upsert(saved_query)
-            except MongoQueryException as e:
-                errors = [str(e)]
+            except MongoQueryException as exception:
+                errors = [str(exception)]
                 return HttpResponseBadRequest(
-                    _render_errors(errors), content_type="application/javascript"
+                    _render_errors(errors),
+                    content_type="application/javascript",
                 )
         else:
             return HttpResponseBadRequest(
                 _render_errors(errors), content_type="application/javascript"
             )
 
-        return HttpResponse(json.dumps({}), content_type="application/javascript")
+        return HttpResponse(
+            json.dumps({}), content_type="application/javascript"
+        )
 
 
 class CreatePersistentQueryExampleUrlView(CreatePersistentQueryUrlView):
@@ -666,6 +714,5 @@ class CreatePersistentQueryExampleUrlView(CreatePersistentQueryUrlView):
         return PersistentQueryExample(
             user_id=query.user_id,
             content=query.content,
-            templates=query.templates,
             data_sources=query.data_sources,
         )
