@@ -6,15 +6,22 @@ from django.urls import reverse_lazy, reverse
 from django.utils.decorators import method_decorator
 from django.views.generic import View
 
-import core_explore_example_app.permissions.rights as rights
+from core_main_app.commons import exceptions as exceptions
+from core_main_app.components.template import api as template_api
+from core_main_app.components.template_version_manager import (
+    api as template_version_manager_api,
+)
+from core_main_app.settings import DATA_SORTING_FIELDS
 import core_main_app.utils.decorators as decorators
+from core_main_app.utils.rendering import render
+
 from core_explore_common_app.components.query import api as query_api
 from core_explore_common_app.settings import DEFAULT_DATE_TOGGLE_VALUE
-from core_explore_common_app.utils.query.query import create_default_query
 from core_explore_common_app.views.user.views import (
     ResultQueryRedirectView,
     ResultsView,
 )
+from core_explore_example_app.permissions import rights
 from core_explore_example_app.components.explore_data_structure import (
     api as explore_data_structure_api,
 )
@@ -24,19 +31,16 @@ from core_explore_example_app.components.persistent_query_example import (
 from core_explore_example_app.components.persistent_query_example.models import (
     PersistentQueryExample,
 )
-from core_explore_example_app.components.saved_query import api as saved_query_api
+from core_explore_example_app.components.saved_query import (
+    api as saved_query_api,
+)
 from core_explore_example_app.settings import INSTALLED_APPS
 from core_explore_example_app.utils.parser import render_form
-from core_main_app.commons import exceptions as exceptions
-from core_main_app.components.template import api as template_api
-from core_main_app.components.template_version_manager import (
-    api as template_version_manager_api,
-)
-from core_main_app.settings import DATA_SORTING_FIELDS
-from core_main_app.utils.rendering import render
 
 
 class IndexView(View):
+    """Index View"""
+
     api = template_version_manager_api
     get_redirect = "core_explore_example_app/user/index.html"
     select_object_redirect = "core_explore_example_select_fields"
@@ -45,8 +49,8 @@ class IndexView(View):
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_access,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_ACCESS,
             login_url=reverse_lazy("core_main_app_login"),
         )
     )
@@ -61,7 +65,9 @@ class IndexView(View):
         """
         assets = {"css": ["core_explore_example_app/user/css/style.css"]}
 
-        global_active_template_list = self.get_global_active_list(request=request)
+        global_active_template_list = self.get_global_active_list(
+            request=request
+        )
         user_active_template_list = self.get_user_active_list(request=request)
 
         context = {
@@ -72,7 +78,12 @@ class IndexView(View):
             "build_query_redirect": self.build_query_redirect,
         }
 
-        return render(request, self.get_redirect, assets=assets, context=context)
+        # Set page title
+        context.update({"page_title": "Explore by Example"})
+
+        return render(
+            request, self.get_redirect, assets=assets, context=context
+        )
 
     def get_global_active_list(self, request):
         """Get all global version managers.
@@ -100,6 +111,8 @@ class IndexView(View):
 
 
 class SelectFieldsView(View):
+    """Select Fields View"""
+
     build_query_url = "core_explore_example_build_query"
     load_form_url = "core_explore_example_load_form"
     generate_element_url = "core_explore_example_generate_element"
@@ -108,8 +121,8 @@ class SelectFieldsView(View):
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_access,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_ACCESS,
             login_url=reverse_lazy("core_main_app_login"),
         )
     )
@@ -127,13 +140,22 @@ class SelectFieldsView(View):
             # Set the assets
             assets = {
                 "js": [
-                    {"path": "core_main_app/common/js/XMLTree.js", "is_raw": False},
-                    {"path": "core_parser_app/js/autosave.js", "is_raw": False},
+                    {
+                        "path": "core_main_app/common/js/XMLTree.js",
+                        "is_raw": False,
+                    },
+                    {
+                        "path": "core_parser_app/js/autosave.js",
+                        "is_raw": False,
+                    },
                     {
                         "path": "core_parser_app/js/autosave_checkbox.js",
                         "is_raw": False,
                     },
-                    {"path": "core_parser_app/js/autosave.raw.js", "is_raw": True},
+                    {
+                        "path": "core_parser_app/js/autosave.raw.js",
+                        "is_raw": True,
+                    },
                     {"path": "core_parser_app/js/buttons.js", "is_raw": False},
                     {
                         "path": "core_explore_example_app/user/js/buttons.raw.js",
@@ -160,12 +182,10 @@ class SelectFieldsView(View):
                 ],
             }
 
-            template = template_api.get(template_id, request=request)
+            template = template_api.get_by_id(template_id, request=request)
             # get data structure
-            data_structure = (
-                explore_data_structure_api.create_and_get_explore_data_structure(
-                    template, request
-                )
+            data_structure = explore_data_structure_api.create_and_get_explore_data_structure(
+                template, request
             )
             root_element = data_structure.data_structure_element_root
 
@@ -183,6 +203,8 @@ class SelectFieldsView(View):
                 "data_structure_id": str(data_structure.id),
                 "xsd_form": xsd_form,
             }
+            # Set page title
+            context.update({"page_title": "Select Fields"})
 
             return render(
                 request,
@@ -190,16 +212,18 @@ class SelectFieldsView(View):
                 assets=assets,
                 context=context,
             )
-        except Exception as e:
+        except Exception as exception:
             return render(
                 request,
                 "core_explore_example_app/user/errors.html",
                 assets={},
-                context={"errors": str(e)},
+                context={"errors": str(exception), "page_title": "Error"},
             )
 
 
 class BuildQueryView(View):
+    """Build Query View"""
+
     build_query_url = "core_explore_example_build_query"
     get_query_url = "core_explore_example_get_query"
     save_query_url = "core_explore_example_save_query"
@@ -215,8 +239,8 @@ class BuildQueryView(View):
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_access,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_ACCESS,
             login_url=reverse_lazy("core_main_app_login"),
         )
     )
@@ -232,7 +256,7 @@ class BuildQueryView(View):
 
         """
         try:
-            template = template_api.get(template_id, request=request)
+            template = template_api.get_by_id(template_id, request=request)
             if template is None:
                 return render(
                     request,
@@ -310,6 +334,9 @@ class BuildQueryView(View):
                 "core_explore_example_app/user/modals/delete_query.html",
             ]
 
+            # Set page title
+            context.update({"page_title": "Build Query"})
+
             return render(
                 request,
                 "core_explore_example_app/user/build_query.html",
@@ -317,12 +344,12 @@ class BuildQueryView(View):
                 context=context,
                 modals=modals,
             )
-        except Exception as e:
+        except Exception as exception:
             return render(
                 request,
                 "core_explore_example_app/user/errors.html",
                 assets={},
-                context={"errors": str(e)},
+                context={"errors": str(exception), "page_title": "Error"},
             )
 
     @staticmethod
@@ -334,17 +361,14 @@ class BuildQueryView(View):
 
         """
         # from the template, we get the version manager
-        template_version_manager = template_version_manager_api.get_by_version_id(
-            str(template.id), request=request
-        )
+        template_version_manager = template.version_manager
         # from the version manager, we get all the version
         template_ids = template_api.get_all_accessible_by_id_list(
             template_version_manager.versions, request=request
         )
         # create query
-        query = create_default_query(request, template_ids)
-        # then upsert
-        return query_api.upsert(query, request.user)
+        query = query_api.create_default_query(request, template_ids)
+        return query
 
     @staticmethod
     def _get_js():
@@ -375,6 +399,10 @@ class BuildQueryView(View):
 
     @staticmethod
     def get_description():
+        """get_description
+
+        Returns
+        """
         # FIXME should be in template
         return (
             "Click on a field of the Query Builder to add an element to your query. "
@@ -388,17 +416,23 @@ class BuildQueryView(View):
 
     @staticmethod
     def get_title():
+        """get_description
+
+        Returns
+        """
         return "Query Builder"
 
 
 class ResultQueryView(ResultsView):
+    """Result Query View"""
+
     back_to_query_redirect = "core_explore_example_build_query"
     get_query_url = "core_explore_example_get_query"
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_access,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_ACCESS,
             login_url=reverse_lazy("core_main_app_login"),
         )
     )
@@ -426,6 +460,7 @@ class ResultQueryView(ResultsView):
             "default_date_toggle_value": DEFAULT_DATE_TOGGLE_VALUE,
             "data_sorting_fields": super().build_sorting_context_array(query),
             "default_data_sorting_fields": ",".join(DATA_SORTING_FIELDS),
+            "back_to_builder": True,
         }
 
         if "core_exporters_app" in INSTALLED_APPS:
@@ -433,9 +468,12 @@ class ResultQueryView(ResultsView):
 
             context["exporter_app"] = True
             context["templates_list"] = json.dumps(
-                [str(template.id) for template in query.templates]
+                [str(template.id) for template in query.templates.all()]
             )
 
+        # Set page title
+        context.update({"page_title": "Query Results"})
+
         return render(
             request,
             "core_explore_example_app/user/results.html",
@@ -460,6 +498,10 @@ class ResultQueryView(ResultsView):
                     "path": "core_explore_example_app/user/js/persistent_query.raw.js",
                     "is_raw": True,
                 },
+                {
+                    "path": "core_main_app/user/js/data/detail.js",
+                    "is_raw": False,
+                },
             ],
             "css": [],
         }
@@ -479,29 +521,33 @@ class ResultQueryView(ResultsView):
 
 
 class ResultQueryExampleRedirectView(ResultQueryRedirectView):
+    """Result Query Example Redirect View"""
+
     model_name = PersistentQueryExample.__name__
     object_name = "persistent_query_example"
     redirect_url = "core_explore_example_results"
 
     @method_decorator(
         decorators.permission_required(
-            content_type=rights.explore_example_content_type,
-            permission=rights.explore_example_access,
+            content_type=rights.EXPLORE_EXAMPLE_CONTENT_TYPE,
+            permission=rights.EXPLORE_EXAMPLE_ACCESS,
             login_url=reverse_lazy("core_main_app_login"),
         )
     )
     def get(self, request, *args, **kwargs):
-        return super(ResultQueryExampleRedirectView, self).get(
-            self, request, *args, **kwargs
-        )
+        return super().get(self, request, *args, **kwargs)
 
     @staticmethod
     def _get_persistent_query_by_id(persistent_query_id, user):
-        return persistent_query_example_api.get_by_id(persistent_query_id, user)
+        return persistent_query_example_api.get_by_id(
+            persistent_query_id, user
+        )
 
     @staticmethod
     def _get_persistent_query_by_name(persistent_query_name, user):
-        return persistent_query_example_api.get_by_name(persistent_query_name, user)
+        return persistent_query_example_api.get_by_name(
+            persistent_query_name, user
+        )
 
     @staticmethod
     def get_url_path():
@@ -514,7 +560,10 @@ class ResultQueryExampleRedirectView(ResultQueryRedirectView):
     def _get_reversed_url(query):
         return reverse(
             ResultQueryExampleRedirectView.redirect_url,
-            kwargs={"template_id": query.templates[0].id, "query_id": query.id},
+            kwargs={
+                "template_id": query.templates.all()[0].id,
+                "query_id": query.id,
+            },
         )
 
     @staticmethod
@@ -531,6 +580,6 @@ def build_sorting_context_array(query):
     """
     context_array = []
     for data_source in query.data_sources:
-        context_array.append(data_source.order_by_field)
+        context_array.append(data_source["order_by_field"])
 
     return ";".join(context_array)
