@@ -1,33 +1,40 @@
 """ Unit Test Persistent Query Example
 """
 
-from tests.components.persistent_query_example.fixtures.fixtures import (
-    PersistentQueryExampleFixtures,
-)
 from django.contrib.auth.models import AnonymousUser
-from core_main_app.utils.tests_tools.MockUser import create_mock_user
+
+
+from core_main_app.access_control.exceptions import AccessControlError
 from core_main_app.utils.integration_tests.integration_base_test_case import (
     MongoIntegrationBaseTestCase,
 )
-
+from core_main_app.utils.tests_tools.MockUser import create_mock_user
+from core_explore_common_app.settings import (
+    CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT,
+)
 import core_explore_example_app.components.persistent_query_example.api as persistent_query_example_api
 from core_explore_example_app.components.persistent_query_example.models import (
     PersistentQueryExample,
 )
-from core_main_app.access_control.exceptions import AccessControlError
-
-from core_explore_common_app.settings import CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT
+from tests.components.persistent_query_example.fixtures.fixtures import (
+    PersistentQueryExampleFixtures,
+)
 
 fixture_persistent_query_example = PersistentQueryExampleFixtures()
 
 
 class TestPersistentQueryExampleGetById(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Get By Id"""
+
     fixture = fixture_persistent_query_example
 
     def test_get_by_id_as_superuser_returns_persistent_query_example(self):
+        """test_get_by_id_as_superuser_returns_persistent_query_example"""
 
         # Arrange
-        persistent_query_example_id = self.fixture.persistent_query_example_1.id
+        persistent_query_example_id = (
+            self.fixture.persistent_query_example_1.id
+        )
         mock_user = create_mock_user("0", is_staff=True, is_superuser=True)
 
         # Act
@@ -36,12 +43,17 @@ class TestPersistentQueryExampleGetById(MongoIntegrationBaseTestCase):
         )
 
         # Assert
-        self.assertTrue(isinstance(persistent_query_example, PersistentQueryExample))
+        self.assertTrue(
+            isinstance(persistent_query_example, PersistentQueryExample)
+        )
 
     def test_get_by_id_as_owner_returns_persistent_query_example(self):
+        """test_get_by_id_as_owner_returns_persistent_query_example"""
 
         # Arrange
-        persistent_query_example_id = self.fixture.persistent_query_example_1.id
+        persistent_query_example_id = (
+            self.fixture.persistent_query_example_1.id
+        )
         mock_user = create_mock_user("1")
 
         # Act
@@ -50,11 +62,19 @@ class TestPersistentQueryExampleGetById(MongoIntegrationBaseTestCase):
         )
 
         # Assert
-        self.assertTrue(isinstance(persistent_query_example, PersistentQueryExample))
+        self.assertTrue(
+            isinstance(persistent_query_example, PersistentQueryExample)
+        )
+
+    def test_get_by_id_as_user_not_owner_returns_persistent_query_example(
+        self,
+    ):
+        """test_get_by_id_as_user_not_owner_returns_persistent_query_example"""
 
-    def test_get_by_id_as_user_not_owner_returns_persistent_query_example(self):
         # Arrange
-        persistent_query_example_id = self.fixture.persistent_query_example_1.id
+        persistent_query_example_id = (
+            self.fixture.persistent_query_example_1.id
+        )
         mock_user = create_mock_user("0")
 
         # Act # Assert
@@ -68,8 +88,12 @@ class TestPersistentQueryExampleGetById(MongoIntegrationBaseTestCase):
         )
 
     def test_get_by_id_as_anonymous_user(self):
+        """test_get_by_id_as_anonymous_user"""
+
         # Arrange
-        persistent_query_example_id = self.fixture.persistent_query_example_1.id
+        persistent_query_example_id = (
+            self.fixture.persistent_query_example_1.id
+        )
 
         # Act # Assert
         if CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT:
@@ -90,12 +114,17 @@ class TestPersistentQueryExampleGetById(MongoIntegrationBaseTestCase):
 
 
 class TestPersistentQueryExampleGetByName(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Get By Name"""
+
     fixture = fixture_persistent_query_example
 
     def test_get_by_name_as_superuser_returns_persistent_query_example(self):
+        """test_get_by_name_as_superuser_returns_persistent_query_example"""
 
         # Arrange
-        persistent_query_example_name = self.fixture.persistent_query_example_1.name
+        persistent_query_example_name = (
+            self.fixture.persistent_query_example_1.name
+        )
         mock_user = create_mock_user("0", is_staff=True, is_superuser=True)
 
         # Act
@@ -104,12 +133,17 @@ class TestPersistentQueryExampleGetByName(MongoIntegrationBaseTestCase):
         )
 
         # Assert
-        self.assertTrue(isinstance(persistent_query_example, PersistentQueryExample))
+        self.assertTrue(
+            isinstance(persistent_query_example, PersistentQueryExample)
+        )
 
     def test_get_by_id_as_owner_returns_persistent_query_example(self):
+        """test_get_by_id_as_owner_returns_persistent_query_example"""
 
         # Arrange
-        persistent_query_example_name = self.fixture.persistent_query_example_1.name
+        persistent_query_example_name = (
+            self.fixture.persistent_query_example_1.name
+        )
         mock_user = create_mock_user("1")
 
         # Act
@@ -118,11 +152,19 @@ class TestPersistentQueryExampleGetByName(MongoIntegrationBaseTestCase):
         )
 
         # Assert
-        self.assertTrue(isinstance(persistent_query_example, PersistentQueryExample))
+        self.assertTrue(
+            isinstance(persistent_query_example, PersistentQueryExample)
+        )
+
+    def test_get_by_id_as_user_not_owner_returns_persistent_query_example(
+        self,
+    ):
+        """test_get_by_id_as_user_not_owner_returns_persistent_query_example"""
 
-    def test_get_by_id_as_user_not_owner_returns_persistent_query_example(self):
         # Arrange
-        persistent_query_example_name = self.fixture.persistent_query_example_1.name
+        persistent_query_example_name = (
+            self.fixture.persistent_query_example_1.name
+        )
         mock_user = create_mock_user("0")
 
         # Act # Assert
@@ -136,8 +178,12 @@ class TestPersistentQueryExampleGetByName(MongoIntegrationBaseTestCase):
         )
 
     def test_get_by_id_as_anonymous_user(self):
+        """test_get_by_id_as_anonymous_user"""
+
         # Arrange
-        persistent_query_example_name = self.fixture.persistent_query_example_1.name
+        persistent_query_example_name = (
+            self.fixture.persistent_query_example_1.name
+        )
 
         # Act # Assert
         if CAN_ANONYMOUS_ACCESS_PUBLIC_DOCUMENT:
@@ -158,38 +204,56 @@ class TestPersistentQueryExampleGetByName(MongoIntegrationBaseTestCase):
 
 
 class TestPersistentQueryExampleDelete(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Delete"""
+
     fixture = fixture_persistent_query_example
 
     def test_delete_others_persistent_query_example_as_superuser_deletes_persistent_query_example(
         self,
     ):
+        """test_delete_others_persistent_query_example_as_superuser_deletes_persistent_query_example"""
+
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
         mock_user = create_mock_user("0", is_staff=True, is_superuser=True)
 
         # Act
-        persistent_query_example_api.delete(persistent_query_example, mock_user)
+        persistent_query_example_api.delete(
+            persistent_query_example, mock_user
+        )
+
+    def test_delete_own_persistent_query_example_deletes_persistent_query_example(
+        self,
+    ):
+        """test_delete_own_persistent_query_example_deletes_persistent_query_example"""
 
-    def test_delete_own_persistent_query_example_deletes_persistent_query_example(self):
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
         mock_user = create_mock_user("1")
 
         # Act
-        persistent_query_example_api.delete(persistent_query_example, mock_user)
+        persistent_query_example_api.delete(
+            persistent_query_example, mock_user
+        )
 
     def test_delete_others_persistent_query_example_raises_error(self):
+        """test_delete_others_persistent_query_example_raises_error"""
+
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
         mock_user = create_mock_user("0")
 
         # Act # Assert
         with self.assertRaises(AccessControlError):
-            persistent_query_example_api.delete(persistent_query_example, mock_user)
+            persistent_query_example_api.delete(
+                persistent_query_example, mock_user
+            )
 
     def test_delete_others_persistent_query_example_as_anonymous_raises_error(
         self,
     ):
+        """test_delete_others_persistent_query_example_as_anonymous_raises_error"""
+
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
 
@@ -201,11 +265,15 @@ class TestPersistentQueryExampleDelete(MongoIntegrationBaseTestCase):
 
 
 class TestPersistentQueryExampleUpdate(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Update"""
+
     fixture = fixture_persistent_query_example
 
     def test_update_others_persistent_query_example_as_superuser_updates_data_structure(
         self,
     ):
+        """test_update_others_persistent_query_example_as_superuser_updates_data_structure"""
+
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
         persistent_query_example.name = "new_name_persistent_query_example_1"
@@ -218,7 +286,11 @@ class TestPersistentQueryExampleUpdate(MongoIntegrationBaseTestCase):
         self.assertTrue(isinstance(result, PersistentQueryExample))
         self.assertTrue(result.name, "new_name_persistent_query_example_1")
 
-    def test_update_own_persistent_query_example_updates_persistent_query_example(self):
+    def test_update_own_persistent_query_example_updates_persistent_query_example(
+        self,
+    ):
+        """test_update_own_persistent_query_example_updates_persistent_query_example"""
+
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
         mock_user = create_mock_user("1")
@@ -232,6 +304,8 @@ class TestPersistentQueryExampleUpdate(MongoIntegrationBaseTestCase):
         self.assertTrue(result.name, "new_name_persistent_query_example_1")
 
     def test_update_others_persistent_query_example_raises_error(self):
+        """test_update_others_persistent_query_example_raises_error"""
+
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
         persistent_query_example.name = "new_name_persistent_query_example_1"
@@ -239,11 +313,14 @@ class TestPersistentQueryExampleUpdate(MongoIntegrationBaseTestCase):
 
         # Act # Assert
         with self.assertRaises(AccessControlError):
-            persistent_query_example_api.upsert(persistent_query_example, mock_user)
+            persistent_query_example_api.upsert(
+                persistent_query_example, mock_user
+            )
 
     def test_update_others_persistent_query_example_as_anonymous_raises_error(
         self,
     ):
+        """test_update_others_persistent_query_example_as_anonymous_raises_error"""
         # Arrange
         persistent_query_example = self.fixture.persistent_query_example_1
 
@@ -255,11 +332,14 @@ class TestPersistentQueryExampleUpdate(MongoIntegrationBaseTestCase):
 
 
 class TestPersistentQueryExampleCreate(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Create"""
+
     fixture = fixture_persistent_query_example
 
     def test_create_others_persistent_query_example_as_superuser_creates_persistent_query_example(
         self,
     ):
+        """test_create_others_persistent_query_example_as_superuser_creates_persistent_query_example"""
         # Arrange
         persistent_query_example = PersistentQueryExample(
             name="new_persistent_query_example", user_id="0"
@@ -276,6 +356,8 @@ class TestPersistentQueryExampleCreate(MongoIntegrationBaseTestCase):
     def test_create_persistent_query_example_as_user_creates_persistent_query_example(
         self,
     ):
+        """test_create_persistent_query_example_as_user_creates_persistent_query_example"""
+
         # Arrange
         persistent_query_example = PersistentQueryExample(
             name="new_persistent_query_example", user_id="1"
@@ -291,6 +373,8 @@ class TestPersistentQueryExampleCreate(MongoIntegrationBaseTestCase):
         self.assertTrue(result.name, "new_persistent_query_example")
 
     def test_create_persistent_query_example_as_anonymous_user(self):
+        """test_create_persistent_query_example_as_anonymous_user"""
+
         # Arrange
         persistent_query_example = PersistentQueryExample(
             name="new_persistent_query_example", user_id="None"
@@ -313,9 +397,13 @@ class TestPersistentQueryExampleCreate(MongoIntegrationBaseTestCase):
 
 
 class TestPersistentQueryExampleGetAll(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Get All"""
+
     fixture = fixture_persistent_query_example
 
     def test_get_all_as_superuser_returns_all_persistent_query_example(self):
+        """test_get_all_as_superuser_returns_all_persistent_query_example"""
+
         # Arrange
         mock_user = create_mock_user("0", is_staff=True, is_superuser=True)
 
@@ -326,6 +414,8 @@ class TestPersistentQueryExampleGetAll(MongoIntegrationBaseTestCase):
         self.assertTrue(len(result), 3)
 
     def test_get_all_as_user_raises_error(self):
+        """test_get_all_as_user_raises_error"""
+
         # Arrange
         mock_user = create_mock_user("1")
 
@@ -334,6 +424,7 @@ class TestPersistentQueryExampleGetAll(MongoIntegrationBaseTestCase):
             persistent_query_example_api.get_all(mock_user)
 
     def test_get_all_as_anonymous_user_raises_error(self):
+        """test_get_all_as_anonymous_user_raises_error"""
 
         # Assert
         with self.assertRaises(AccessControlError):
@@ -341,11 +432,15 @@ class TestPersistentQueryExampleGetAll(MongoIntegrationBaseTestCase):
 
 
 class TestPersistentQueryExampleGetAllByUser(MongoIntegrationBaseTestCase):
+    """Test Persistent Query Example Get All By User"""
+
     fixture = fixture_persistent_query_example
 
     def test_get_all_by_user_as_superuser_returns_all_user_persistent_query_example(
         self,
     ):
+        """test_get_all_by_user_as_superuser_returns_all_user_persistent_query_example"""
+
         # Arrange
         mock_user = create_mock_user("1", is_staff=True, is_superuser=True)
 
@@ -356,6 +451,8 @@ class TestPersistentQueryExampleGetAllByUser(MongoIntegrationBaseTestCase):
         self.assertTrue(len(result), 1)
 
     def test_get_all_by_user_returns_all_user_persistent_query_example(self):
+        """test_get_all_by_user_returns_all_user_persistent_query_example"""
+
         # Arrange
         mock_user = create_mock_user("1")
 
